@@ -1,7 +1,7 @@
 #' Supervised Factor Conversions into Linear Functions using Bayesian Likelihood
 #' Encodings
 #'
-#' `step_lencode_bayes` creates a *specification* of a recipe step that will
+#' `step_lencode_bayes()` creates a *specification* of a recipe step that will
 #' convert a nominal (i.e. factor) predictor into a single set of scores derived
 #' from a generalized linear model estimated using Bayesian analysis.
 #'
@@ -243,10 +243,14 @@ stan_coefs <- function(x, y, options, verbose, wts = NULL, ...) {
 
 #' @export
 bake.step_lencode_bayes <- function(object, new_data, ...) {
-  check_new_data(names(object$mapping), object, new_data)
+  col_names <- names(object$mapping)
+  check_new_data(col_names, object, new_data)
 
-  for (col in names(object$mapping)) {
-    new_data[, col] <- map_glm_coef(new_data[, col], object$mapping[[col]])
+  for (col_name in col_names) {
+    new_data[[col_name]] <- map_glm_coef(
+      new_data[, col_name], # map_glm_coef() expects a tibble
+      object$mapping[[col_name]]
+    )
   }
 
   new_data
