@@ -1,7 +1,7 @@
 #' Supervised Factor Conversions into Linear Functions using Bayesian Likelihood
 #' Encodings
 #'
-#' `step_lencode_mixed` creates a *specification* of a recipe step that will
+#' `step_lencode_mixed()` creates a *specification* of a recipe step that will
 #' convert a nominal (i.e. factor) predictor into a single set of scores derived
 #' from a generalized linear mixed model.
 #'
@@ -237,10 +237,14 @@ map_lme_coef <- function(dat, mapping) {
 
 #' @export
 bake.step_lencode_mixed <- function(object, new_data, ...) {
-  check_new_data(names(object$mapping), object, new_data)
+  col_names <- names(object$mapping)
+  check_new_data(col_names, object, new_data)
 
-  for (col in names(object$mapping)) {
-    new_data[, col] <- map_lme_coef(new_data[, col], object$mapping[[col]])
+  for (col_name in col_names) {
+    new_data[[col_name]] <- map_lme_coef(
+      dat = new_data[, col_name], # map_glm_coef() expects a tibble
+      mapping = object$mapping[[col_name]]
+    )
   }
 
   new_data
